```python
from fake_useragent import UserAgent

ua = UserAgent()
print(ua.o)
print(ua.ie)   #随机打印ie浏览器任意版本
print(ua.firefox) #随机打印firefox浏览器任意版本
print(ua.chrome)  #随机打印chrome浏览器任意版本
print(ua.random)  #随机打印任意厂家的浏览器
```
- userAgent
- proxy
- cookies